DS18B20 - Heros Devices 0.7.1 documentation

Skip to content
Back to top
View this page

# DS18B20

From: Analog Devices

Class: `herosdevices.hardware.analog_devices.ds18b20.DS18B20`

Driver Quality Index: beta

One wire temperature sensor type DS18B20.

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.analog_devices.ds18b20.DS18B20` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
device_id | <class ‘str’> |  | id of the onewire device as named by the w1 Linux kernel driver.
sysfs_path | <class ‘str’> | /sys/bus/w1/ | sys path of the Linux w1 kernel driver

The following JSON strings can be used to start a HERO device representation of `DS18B20` using BOSS.

    {
        "_id": "temp-main-table",
        "classname": "herosdevices.hardware.analog_devices.DS18B20",
        "arguments": {
            "device_id": "28-06201996d98f"
        },
        "datasource": {
            "async": false,
            "interval": 5,
            "observables": {
                "temperature": {
                    "conversion": "x/1000.",
                    "unit": "degC",
                    "boundaries": [
                        [
                            21,
                            22
                        ],
                        [
                            20,
                            24
                        ],
                        [
                            15,
                            30
                        ]
                    ]
                }
            }
        }
    }

from examples/analog_devices/ds18b20.json

    {
        "_id": "my_DS18B20",
        "classname": "herosdevices.hardware.analog_devices.ds18b20.DS18B20",
        "arguments": {
            "device_id": "<class 'str'>",
            "sysfs_path": "/sys/bus/w1/"
        }
    }

generated from signature